@@ -8,18 +8,19 @@
 #' @param network The network of the NRCS/AWDB site of interest. Currently only works for options: 'SCAN','SNTL','SNTLT', and 'OTHER'.\cr
 #' @param site_id The NRCS site ID. Use grabNRCS.meta to retrieve a list of available sites in a specified network. Consider using the package 'metScanR' to locate sites.\cr
 #' @param timescale Specify the desired timescale of the data. Typically 'hourly', 'daily', or 'monthly'\cr
-#' @param DayBgn Optional. Specify the beginning date (as YYYY-MM-DD ) for the returned data, otherwise the beginning of the period of record is returned.\cr
-#' @param DayEnd Optional. Specify the end date (as YYYY-MM-DD ) for the returned data, otherwise the end of the period of record is returned.\cr
+#' @param DayBgn Specify the beginning date (as YYYY-MM-DD ) for the returned data.\cr
+#' @param DayEnd Specify the end date (as YYYY-MM-DD ) for the returned data.\cr
 #'
-#' @return Returns a data frame of requested data and a list of varaibles with no data.\cr
+#' @return Returns a data frame of requested data. Only elements with at least one data will be returned in the data frame.\cr
 
 #' @keywords environment, data, environmental data, atmosphere, atmopsheric data, climate, in-situ, weather\cr
 
 #' @references Downloads <https://wcc.sc.egov.usda.gov/reportGenerator>
 #'
 #' @examples
-#' grabNRCS.data(network="SNTLT", site_id=1198, timescale="monthly")
-#' #Return monthly summaries for the period of record at a SNOLITE site.
+#' grabNRCS.data(network="SNTLT", site_id=1198, timescale="monthly",
+#' DayBgn = '2017-01-01', DayEnd = '2017-05-01')
+#' #Return monthly summaries between January and May 2017 of record at a SNOLITE site.
 
 #' @seealso Currently none
 
@@ -27,7 +28,10 @@
 
 # changelog and author contributions / copyrights
 #   Robert Lee (2017-04-03)
-#     original creation
+#     Original creation
+#   Robert Lee (2017-07-06)
+#    Removed period of record calls, soil elements,
+#    and swithced to read.csv for data return
 ##############################################################################################
 
 grabNRCS.data<-function(network, site_id, timescale, DayBgn, DayEnd){
@@ -38,10 +42,6 @@ grabNRCS.data<-function(network, site_id, timescale, DayBgn, DayEnd){
     #load element info
     eCodes<-RNRCS::elementCodes
 
-    #Default to period of record for station if dates not specified.
-    if(missing(DayBgn)){DayBgn<-"POR_BEGIN"}
-    if(missing(DayEnd)){DayEnd<-"POR_END"}
-
     #Stick to the appropriate timescales
     ctrlTimeScale<-c("hourly", "daily", "monthly")
     if (!timescale %in% ctrlTimeScale){stop("Please enter one of the following for timescale: 'hourly', 'daily', 'monthly'")}
@@ -67,40 +67,41 @@ grabNRCS.data<-function(network, site_id, timescale, DayBgn, DayEnd){
     eCodeString<-do.call(paste, c(as.list(siteEcodes), sep = "::value,"))
     eCodeString<-paste0(eCodeString, "::value")
 
+#     Soil temperature and moisture are currently broken, will implement again later
+#     stoString<-"STO:-2:value:hourly MEAN,STO:-4:value:hourly MEAN,STO:-8:value:hourly MEAN,STO:-20:value:hourly MEAN,STO:-40:value:hourly MEAN,"
+#     smsString<-"SMS:-2:value:hourly MEAN,SMS:-4:value:hourly MEAN,SMS:-8:value:hourly MEAN,SMS:-20:value:hourly MEAN,SMS:-40:value:hourly MEAN,"
+#
+#
+#      eCodeString<-gsub(pattern="STO::value", replacement = stoString, eCodeString)
+#      eCodeString<-gsub(pattern="SMS::value", replacement = stoString, eCodeString)
 
-    stoString<-"STO:-2:value:hourly MEAN,STO:-4:value:hourly MEAN,STO:-8:value:hourly MEAN,STO:-20:value:hourly MEAN,STO:-40:value:hourly MEAN"
-    smsString<-"SMS:-2:value:hourly MEAN,SMS:-4:value:hourly MEAN,SMS:-8:value:hourly MEAN,SMS:-20:value:hourly MEAN,SMS:-40:value:hourly MEAN"
-
-
-    eCodeString<-gsub(pattern="STO::value", replacement = stoString, eCodeString)
-    eCodeString<-gsub(pattern="SMS::value", replacement = stoString, eCodeString)
-    #Build data URL
+     eCodeString<-gsub(pattern="STO::value,", replacement = "", eCodeString)
+     eCodeString<-gsub(pattern="SMS::value,", replacement = "", eCodeString)
+    # #Build data URL
     baseURL <- "https://wcc.sc.egov.usda.gov/reportGenerator/view_csv/customSingleStationReport/"
 
     fullURL <- paste0(baseURL, timescale, "/", site_id, ":", site_state, ':', network, '|id=""|name/', DayBgn, ",", DayEnd, '/', eCodeString)
 
-    rawData<- readLines(fullURL)
-    onlyData<-rawData[-grep("^[#]", rawData)]
-    topline<-onlyData[1]
-
-
-    #Add NAs in for blank entries, need to do twice to catch all
-    onlyData<-paste0(onlyData[grep(",$", onlyData)], "NA")
-    onlyData<-gsub(pattern = ",,", replacement = ",NA,", onlyData)
-    onlyData<-gsub(pattern = ",,", replacement = ",NA,", onlyData)
-
-    onlyData<-append(topline, onlyData)
-    dfNRCS <- data.frame(do.call('rbind', strsplit(as.character(onlyData),',',fixed=TRUE)))
-    colnames(dfNRCS)<-dfNRCS[1,]
-    dfNRCS[dfNRCS=="NA"]=NA
-
-    # Remove all NA columns, and report which data varaiables they were
-    tempDF<-as.data.frame(dfNRCS[-1,])
-    missingVars<-names(which(colSums(is.na(tempDF))==nrow(tempDF)))
-    missingVars<-missingVars
-
-    # Output the final results to the global environment
+    # rawData<- readLines(fullURL)
+    # onlyData<-rawData[-grep("^[#]", rawData)]
+    # topline<-onlyData[1]
+    #
+    # <-read.csv(fullURL, header = T, comment.char = "#")
+    #
+    # #Add NAs in for blank entries, need to do twice to catch all
+    # onlyData<-paste0(onlyData[grep(",$", onlyData)], "NA")
+    # onlyData<-gsub(pattern = ",,", replacement = ",NA,", onlyData)
+    # onlyData<-gsub(pattern = ",,", replacement = ",NA,", onlyData)
+    #
+    # onlyData<-append(topline, onlyData)
+    # dfNRCS <- data.frame(do.call('rbind', strsplit(as.character(onlyData),',',fixed=TRUE)))
+    # colnames(dfNRCS)<-dfNRCS[1,]
+    # dfNRCS[dfNRCS=="NA"]=NA
+    tempDF<-utils::read.csv(fullURL, comment.char = "#", quote = "")
+    if(ncol(tempDF)==1){stop("The NRCS API is currently unavailable, please try again later.")}
+    # Remove all NA columns, output the final results to the global environment
     NRCS.df<-tempDF[,-which(colSums(is.na(tempDF))==nrow(tempDF))]
+
     return(NRCS.df)
 }
 
